#
# spec file for package apache-commons-daemon
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define short_name commons-daemon

Name:           apache-%{short_name}
Version:        1.0.15
Release:        13.4
Summary:        Commons Daemon - Controlling of Java Daemons
License:        Apache-2.0
Group:          System/Daemons
Url:            http://commons.apache.org/daemon/
Source0:        http://www.eu.apache.org/dist/commons/daemon/source/commons-daemon-%{version}-src.tar.gz
Source1:        http://www.eu.apache.org/dist/commons/daemon/source/commons-daemon-%{version}-src.tar.gz.asc
Source2:        apache-commons-daemon.keyring
Patch0:         apache-commons-daemon-JAVA_OS.patch
Patch1:         apache-commons-daemon-s390x.patch
Patch2:         apache-commons-daemon-ppc64.patch
Patch3:         apache-commons-daemon-aarch64.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  ant
BuildRequires:  apache-commons-parent
BuildRequires:  java-devel
BuildRequires:  javapackages-tools
BuildRequires:  libcap-devel
BuildRequires:  xmlto

%if 0%{?suse_version} >= 1230
BuildRequires:  gpg-offline
%endif

Provides:       jakarta-%{short_name} = %{version}-%{release}
Obsoletes:      jakarta-%{short_name} < %{version}
Provides:       jakarta-%{short_name}-java = %{version}-%{release}
Obsoletes:      jakarta-%{short_name}-java < %{version}

%description
The Daemon Component contains a set of Java and native code, including
a set of Java interfaces applications must implement and Unix native
code to control a Java daemon from a Unix operating system.

%package        jsvc
Summary:        Java daemon launcher
Group:          System/Daemons
Provides:       jsvc = %{version}-%{release}
Obsoletes:      jsvc < %{version}
Provides:       jakarta-%{short_name}:%{_sbindir}/jsvc

%description    jsvc
Jsvc is a set of libraries and applications for making Java applications run on
UNIX more easily. It allows the application (e.g. Tomcat) to perform some
privileged operations as root (e.g. bind to a port < 1024), and then switch
identity to a non-privileged user.

%package javadoc
BuildArch:      noarch
Summary:        Commons Daemon Javadoc
Group:          Documentation/Other

Provides:       jakarta-%{short_name}-javadoc = %{version}-%{release}
Obsoletes:      jakarta-%{short_name}-javadoc < %{version}

%description javadoc
The Javadoc Documentation for Commons Daemon. 


%prep
%if 0%{?suse_version} >= 1230
%gpg_verify %{SOURCE1}
%endif
%setup -q -n %{short_name}-%{version}-src
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# remove java binaries from sources
rm -rf src/samples/build/

# remove files for different OS
rm -rf src/samples/*.cmd

chmod -R 0644 src/samples/*

%build
pushd src/native/unix
xmlto man man/jsvc.1.xml

# build native jsvc
%configure --with-java=%{java_home}
# this is here because 1.0.2 archive contains old *.o
make clean
make %{?_smp_mflags}
popd
ant jar test javadoc

%install

# install native jsvc
install -Dm 0755 src/native/unix/jsvc %{buildroot}%{_bindir}/jsvc
install -Dpm 644 src/native/unix/jsvc.1 $RPM_BUILD_ROOT%{_mandir}/man1/jsvc.1

# jars
install -Dpm 644 dist/%{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}.jar
ln -sf %{name}.jar %{buildroot}%{_javadir}/%{short_name}.jar

# pom
install -Dpm 644 pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar -a "org.apache.commons:%{short_name}"

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}
cp -pr dist/docs/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc LICENSE.txt PROPOSAL.html NOTICE.txt RELEASE-NOTES.txt src/samples
%{_javadir}/%{name}.jar
%{_javadir}/%{short_name}.jar
%{_mavenpomdir}/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}

%files jsvc
%defattr(-,root,root)
%doc LICENSE.txt
%{_bindir}/jsvc
%{_mandir}/man1/jsvc.1*

%files javadoc
%defattr(-,root,root)
%doc LICENSE.txt
%doc src/docs/*
%doc %{_javadocdir}/%{name}

%changelog
* Fri Sep 13 2013 mvyskocil@suse.com
- add javapackages-tools to build requires
* Thu May 16 2013 mvyskocil@suse.com
- update to 1.0.15
  * bugfix release, see RELEASE-NOTES.txt for a list of fixed bugs
- obsoleted patches:
  * 0001-execve-path-warning.patch, already upstream
  * jsvc-libcap-relative.patch, already upstream
  * config-guess-sub-update.patch, already upstream
- don't install pointless filesfor SUSE Linux
- verify package signature on openSUSE 12.3+
- use source urls
* Mon Mar 25 2013 schwab@suse.de
- config-guess-sub-update.patch: update config.guess/sub for aarch64
- apache-commons-daemon-aarch64.patch: add aarch64 to the list of
  supported cpus
* Thu Jul 19 2012 mvyskocil@suse.cz
- fix bnc#771802: jsvc fails to load libcap
* Tue Jul  3 2012 dvaleev@suse.com
- read ppc64 as known platform.
* Fri Jun 15 2012 mvyskocil@suse.cz
- Update to 1.0.10 (bugfix release)
- Rename to apache-commons-daemon
  * put the binary to -jsvc package
  * return jars from -java package to main one
- Obsoleted ppc patch
* Mon Apr  2 2012 dvaleev@suse.com
- fix ppc64 architecture detection
* Tue Sep  6 2011 mvyskocil@suse.cz
- Update to 1.0.7
  * fix bnc#CVE-2011-2729/bnc#715656
  * proper file closing  and other minor fixes
* Wed Jan 19 2011 bitshuffler@opensuse.org
- Updated to 1.0.5.
- Reworked spec.
- Removed obsolete patches.
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Mon Sep 25 2006 skh@suse.de
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 jsmeix@suse.de
- Current version 1.0.1 from JPackage.org
* Wed Jul 27 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Wed Jul 20 2005 jsmeix@suse.de
- Current version 1.0 from JPackage.org
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 1.0 from JPackage.org
* Thu Sep 16 2004 skh@suse.de
- Fix prerequires of javadoc subpackage
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 1.0 (JPackage 1.5)
